@@ -20,8 +20,6 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Base/Size.h>
-
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Header.h>
 #include <Lum/Model/Integer.h>
@@ -29,15 +27,10 @@
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-#include <Lum/OS/Image.h>
-
-#include <Lum/Dialog.h>
-#include <Lum/Image.h>
 #include <Lum/Object.h>
 #include <Lum/Popup.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
-#include <Lum/TableView.h>
 
 namespace Lum {
   /**
@@ -56,26 +49,14 @@ namespace Lum {
   class LUMAPI Combo : public Control
   {
   private:
-    class Table : public ::Lum::TableView
-    {
-    public:
-      bool             success;
-
-    public:
-      Table();
-      ~Table();
-
-      void Resync(Base::Model* model, const Base::ResyncMsg& msg);
-    };
-
     class ComboPopup : public Popup
     {
     public:
       Combo *combo;
+      bool  success;
 
     public:
       ComboPopup(Combo *combo);
-      ~ComboPopup();
       void PreInit();
       void Resync(Base::Model* model, const Base::ResyncMsg& msg);
     };
@@ -83,14 +64,14 @@ namespace Lum {
   private:
     bool                          imageRight;
     bool                          editable;
-    ::Lum::Table                  *table;
-    Popup*                        popup;
+    Table                         *table;
+    ComboPopup*                   popup;
 
   protected:
     Model::ActionRef              prevAction;
     Model::ActionRef              nextAction;
     Model::HeaderRef              headerModel; /** The header model used for the table in the popup */
-    Model::TableRef               tableModel; /** The table model used for the table in the popup */
+    Model::TableRef               tableModel;  /** The table model used for the table in the popup */
     Model::SingleLineSelectionRef selection;
     Object                        *value; /**
                                            The object used to display the current
@@ -122,8 +103,6 @@ namespace Lum {
     void CalcSize();
     void Layout();
 
-    virtual void InitTable(::Lum::Table* table);
-
     bool HandleMouseEvent(const OS::MouseEvent& event);
     bool HandleKeyEvent(const OS::KeyEvent& event);
 
