@@ -39,6 +39,10 @@ namespace Lum {
         CustomMenuHandler* GetCustomMenuHandler(OS::Window* window) const;
         void ApplyMultiViewDlg(Dialog* dialog,
                                const Def::MultiView& multiView) const;
+        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def) const;
+        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def,
+                                         bool horizFlex,
+                                         bool vertFlex) const;
       };
     }
   }
