@@ -58,10 +58,17 @@ namespace Lum {
         void PushUniqueFill(OS::DrawInfo* draw, size_t index, size_t maximum);
         void PopUniqueFill(OS::DrawInfo* draw, size_t index, size_t maximum);
 
+        size_t GetHorizontalFuelBarMinWidth() const;
+        size_t GetHorizontalFuelBarMinHeight() const;
+        size_t GetVerticalFuelBarMinWidth() const;
+        size_t GetVerticalFuelBarMinHeight() const;
+
         int GetSubMenuHorizontalOffset() const;
         bool OptimizeMenus() const;
         size_t MaxPopupMenuEntries() const;
 
+        unsigned long GetCursorBlinkTimeMicroSeconds() const;
+
         bool RequestFingerFriendlyControls() const;
         Lum::Base::Size GetFingerFriendlyMinWidth() const;
         Lum::Base::Size GetFingerFriendlyMinHeight() const;
@@ -72,6 +79,8 @@ namespace Lum {
         bool SubdialogsAlwaysFlexHoriz() const;
         bool SubdialogsAlwaysFlexVert() const;
 
+        bool PopupsAreDialogs() const;
+
         DialogActionPosition GetDialogActionPosition() const;
         bool ImplicitCancelAction() const;
         bool ImplicitDefaultAction() const;
