@@ -26,12 +26,13 @@ namespace Lum {
   namespace OS {
     namespace Hildon {
 
-      class Behaviour : public OS::Base::Behaviour
+      class Behaviour : public OS::Base::DefaultBehaviour
       {
       public:
         CustomMenuHandler* GetCustomMenuHandler(OS::Window* window) const;
         void ApplyMultiViewDlg(Dialog* dialog,
                                const Def::MultiView& multiView) const;
+        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def) const;
       };
 
     }
