@@ -133,6 +133,11 @@ namespace Lum {
       virtual size_t GetFirstTabOffset() const = 0;
       virtual size_t GetLastTabOffset() const = 0;
 
+      virtual size_t GetHorizontalFuelBarMinWidth() const = 0;
+      virtual size_t GetHorizontalFuelBarMinHeight() const = 0;
+      virtual size_t GetVerticalFuelBarMinWidth() const = 0;
+      virtual size_t GetVerticalFuelBarMinHeight() const = 0;
+
       /**
         How many pixels must the mouse move before this is recognized as drag start?
       */
@@ -144,6 +149,14 @@ namespace Lum {
       virtual size_t GetMouseClickHoldSensitivity() const = 0;
       //@}
 
+      /**
+        @name Timing
+        Timing information like cursor blink time etc.
+      */
+      //@{
+      virtual unsigned long GetCursorBlinkTimeMicroSeconds() const = 0;
+      //@}
+
       /**
         @name Variants and behaviours
         Choosing between display variants and different behaviours.
@@ -167,6 +180,8 @@ namespace Lum {
       virtual bool SubdialogsAlwaysFlexHoriz() const = 0;
       virtual bool SubdialogsAlwaysFlexVert() const = 0;
 
+      virtual bool PopupsAreDialogs() const = 0;
+
       virtual DialogActionPosition GetDialogActionPosition() const =0;
       virtual bool ImplicitCancelAction() const =0;
       virtual bool ImplicitDefaultAction() const =0;
