@@ -119,6 +119,7 @@ namespace Lum {
     int              cursorPos;        //! Absolute position of cursor
     OS::FontRef      font;             //! Font to use
     Model::StringRef model;            //! Value model
+    std::wstring     label;            //! Optional label, shwown if no value and no focus
     bool             selected;         //! The is currently a selection
     bool             readOnly;         //! The control is read only
     bool             cursorVisible;    //! The cursor is currently visible (=> cursor blinking)
@@ -174,7 +175,9 @@ namespace Lum {
     // Setter
     bool SetModel(Base::Model* model);
 
-    void SetInputHelper(InputHelper *inputHelper);
+    String* SetLabel(const std::wstring& label);
+
+    String* SetInputHelper(InputHelper *inputHelper);
 
     void SetCursorUpAction(Model::Action* action);
     void SetCursorDownAction(Model::Action* action);
