@@ -40,7 +40,10 @@ namespace Lum {
   {
     SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
 
-    SetCanFocus(true);
+    if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+      SetCanFocus(true);
+    }
+
     SetRedrawOnMouseActive(true);
   }
 
@@ -118,7 +121,12 @@ namespace Lum {
     if (pos!=std::wstring::npos && pos+1<string.length()) {
       shortCut=string[pos+1];
       text->AddText(string.substr(0,pos));
-      text->AddText(string.substr(pos+1,1),OS::Font::underlined);
+      if (OS::display->GetTheme()->ShowKeyShortcuts()) {
+        text->AddText(string.substr(pos+1,1),OS::Font::underlined);
+      }
+      else {
+        text->AddText(string.substr(pos+1,1));
+      }
       text->AddText(string.substr(pos+2));
     }
     else {
@@ -182,43 +190,66 @@ namespace Lum {
     switch (type) {
       case typeNormal:
       SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
-      RequestFocus();
+      if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+        RequestFocus();
+      }
+
       if (OS::display->GetTheme()->RequestFingerFriendlyControls()) {
-        SetMinWidth(Lum::Base::Size::mm,9);
-        SetMinHeight(Lum::Base::Size::mm,9);
+        SetMinWidth(OS::display->GetTheme()->GetFingerFriendlyMinWidth());
+        SetMinHeight(OS::display->GetTheme()->GetFingerFriendlyMinHeight());
       }
       break;
     case typeDefault:
       SetBackground(OS::display->GetFill(OS::Display::defaultButtonBackgroundFillIndex));
-      RequestFocus();
+
+      if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+        RequestFocus();
+      }
+
       if (OS::display->GetTheme()->RequestFingerFriendlyControls()) {
-        SetMinWidth(Lum::Base::Size::mm,9);
-        SetMinHeight(Lum::Base::Size::mm,9);
+        SetMinWidth(OS::display->GetTheme()->GetFingerFriendlyMinWidth());
+        SetMinHeight(OS::display->GetTheme()->GetFingerFriendlyMinHeight());
       }
       break;
     case typeCommit:
       SetBackground(OS::display->GetFill(OS::Display::positiveButtonBackgroundFillIndex));
-      RequestFocus();
+
+      if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+        RequestFocus();
+      }
+
       if (OS::display->GetTheme()->RequestFingerFriendlyControls()) {
-        SetMinWidth(Lum::Base::Size::mm,9);
-        SetMinHeight(Lum::Base::Size::mm,9);
+        SetMinWidth(OS::display->GetTheme()->GetFingerFriendlyMinWidth());
+        SetMinHeight(OS::display->GetTheme()->GetFingerFriendlyMinHeight());
       }
       break;
     case typeCancel:
       SetBackground(OS::display->GetFill(OS::Display::negativeButtonBackgroundFillIndex));
-      RequestFocus();
+
+      if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+        RequestFocus();
+      }
+
       if (OS::display->GetTheme()->RequestFingerFriendlyControls()) {
-        SetMinWidth(Lum::Base::Size::mm,9);
-        SetMinHeight(Lum::Base::Size::mm,9);
+        SetMinWidth(OS::display->GetTheme()->GetFingerFriendlyMinWidth());
+        SetMinHeight(OS::display->GetTheme()->GetFingerFriendlyMinHeight());
       }
       break;
     case typeIcon:
       SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
-      RequestFocus();
+
+      if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+        RequestFocus();
+      }
+
       break;
     case typeAdditional:
       SetBackground(OS::display->GetFill(OS::Display::buttonBackgroundFillIndex));
-      RequestFocus();
+
+      if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+        RequestFocus();
+      }
+
       break;
     case typeToolBar:
       SetBackground(OS::display->GetFill(OS::Display::toolbarButtonBackgroundFillIndex));
@@ -618,7 +649,7 @@ namespace Lum {
   }
 
   Button* Button::Create(const std::wstring& text,
-                         Lum::OS::Theme::StockImage image,
+                         OS::Theme::StockImage image,
                          Base::Model* action,
                          Type type,
                          bool horizontalFlex, bool verticalFlex)
