@@ -23,29 +23,6 @@
 
 namespace Lum {
 
-  Combo::Table::Table()
-  : success(false)
-  {
-    Observe(GetMouseSelectionAction());
-  }
-
-  Combo::Table::~Table()
-  {
-    // no code
-  }
-
-  void Combo::Table::Resync(Base::Model* model,
-                            const Base::ResyncMsg& msg)
-  {
-    if (model==GetMouseSelectionAction() && GetMouseSelectionAction()->IsFinished()) {
-      success=true;
-      GetWindow()->Exit();
-    }
-    else {
-      TableView::Resync(model,msg);
-    }
-  }
-
   Combo::Combo(Object* value, bool editable)
   : imageRight(true),
     editable(editable),
@@ -200,24 +177,9 @@ namespace Lum {
     Control::CalcSize();
   }
 
-  /**
-    Overload this method if you want some inital initialisation of the table
-    object used for the popup window. The baseclass is empty.
-
-    Normally this will be done by a concrete implementation of Combo.
-  */
-  void Combo::InitTable(::Lum::Table* /*table*/)
-  {
-    // no code
-  }
-
   Combo::ComboPopup::ComboPopup(Combo *combo)
-  : combo(combo)
-  {
-    Observe(GetOpenedAction());
-  }
-
-  Combo::ComboPopup::~ComboPopup()
+  : combo(combo),
+    success(false)
   {
     // no code
   }
@@ -225,22 +187,29 @@ namespace Lum {
   void Combo::ComboPopup::PreInit()
   {
     combo->table=new Lum::Table();
-
-    combo->table->SetTableView(new Table());
     combo->table->SetFlex(true,true);
     combo->table->SetMinHeight(Base::Size::stdCharHeight,1);
-    combo->table->SetMaxWidth(Base::Size::workHRel,80);
-    combo->table->SetMaxHeight(Base::Size::workVRel,40);
-    combo->table->GetTableView()->SetAutoFitColumns(true);
+
+    if (OS::display->GetTheme()->PopupsAreDialogs()) {
+      combo->table->SetMaxWidth(Base::Size::workHRel,100);
+      combo->table->SetMaxHeight(Base::Size::workVRel,100);
+    }
+    else {
+      combo->table->SetMaxWidth(Base::Size::workHRel,80);
+      combo->table->SetMaxHeight(Base::Size::workVRel,40);
+    }
+
     combo->table->SetHeaderModel(combo->headerModel);
     combo->table->SetModel(combo->tableModel);
     combo->table->SetSelection(combo->selection);
+    combo->table->GetTableView()->SetAutoFitColumns(true);
     combo->table->GetTableView()->SetAutoHSize(true);
     combo->table->GetTableView()->SetAutoVSize(true);
+
     RegisterCommitShortcut(combo->table->GetTableView(),
                            combo->table->GetTableView()->GetMouseSelectionAction());
-
-    combo->InitTable(combo->table);
+    Observe(combo->table->GetTableView()->GetMouseSelectionAction());
+    Observe(GetPreOpenedAction());
 
     SetMain(combo->table,true,false);
 
@@ -249,11 +218,20 @@ namespace Lum {
 
   void Combo::ComboPopup::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
-    if (model==GetOpenedAction() && GetOpenedAction()->IsFinished()) {
+    if (combo->table!=NULL &&
+        combo->table->GetTableView()!=NULL &&
+        model==GetPreOpenedAction() && GetPreOpenedAction()->IsFinished()) {
       if (combo->tableModel.Valid() && combo->selection->GetLine()>0) {
         combo->table->GetTableView()->MakeVisible(1,combo->selection->GetLine());
       }
     }
+    else if (combo->table!=NULL &&
+             combo->table->GetTableView()!=NULL &&
+             model==combo->table->GetTableView()->GetMouseSelectionAction() &&
+             combo->table->GetTableView()->GetMouseSelectionAction()->IsFinished()) {
+      success=true;
+      Exit();
+    }
 
     Popup::Resync(model,msg);
   }
@@ -268,7 +246,9 @@ namespace Lum {
       popup->EventLoop();
       popup->Close();
 
-      if (dynamic_cast<Table*>(table->GetTableView())->success && tableModel.Valid() && selection->HasSelection()) {
+      if (popup->success &&
+          tableModel.Valid() &&
+          selection->HasSelection()) {
         CopySelection(selection->GetLine());
       }
     }
