@@ -48,40 +48,50 @@ namespace Lum {
 
   size_t Label::Entry::GetMinHeight() const
   {
-    size_t height=0;
-
-    if (label!=NULL) {
-      height=std::max(height,label->GetOMinHeight());
+    if (label!=NULL && object!=NULL &&
+        label->HasBaseline() && object->HasBaseline()) {
+      return std::max(label->GetBaseline(),
+                      object->GetBaseline())+
+             std::max(label->GetOMinHeight()-label->GetBaseline(),
+                      object->GetOMinHeight()-object->GetBaseline());
     }
+    else {
+      size_t height=0;
 
-    if (object!=NULL) {
-      height=std::max(height,object->GetOMinHeight());
+      if (label!=NULL) {
+        height=std::max(height,label->GetOMinHeight());
+      }
+
+      if (object!=NULL) {
+        height=std::max(height,object->GetOMinHeight());
+      }
+
+      return height;
     }
-
-    if (label!=NULL && object!=NULL && label->HasBaseline() && object->HasBaseline()) {
-      height+=std::max(label->GetBaseline(),object->GetBaseline())-std::min(label->GetBaseline(),object->GetBaseline());
-    }
-
-    return height;
   }
 
   size_t Label::Entry::GetHeight() const
   {
-    size_t height=0;
-
-    if (label!=NULL) {
-      height=std::max(height,label->GetOHeight());
+    if (label!=NULL && object!=NULL &&
+        label->HasBaseline() && object->HasBaseline()) {
+      return std::max(label->GetBaseline(),
+                      object->GetBaseline())+
+             std::max(label->GetOHeight()-label->GetBaseline(),
+                      object->GetOHeight()-object->GetBaseline());
     }
+    else {
+      size_t height=0;
 
-    if (object!=NULL) {
-      height=std::max(height,object->GetOHeight());
+      if (label!=NULL) {
+        height=std::max(height,label->GetOHeight());
+      }
+
+      if (object!=NULL) {
+        height=std::max(height,object->GetOHeight());
+      }
+
+      return height;
     }
-
-    if (label!=NULL && object!=NULL && label->HasBaseline() && object->HasBaseline()) {
-      height+=std::max(label->GetBaseline(),object->GetBaseline())-std::min(label->GetBaseline(),object->GetBaseline());
-    }
-
-    return height;
   }
 
   size_t Label::Entry::CanResize(bool grow) const
@@ -102,8 +112,10 @@ namespace Lum {
 
   void Label::Entry::Resize(size_t height)
   {
-    if (label!=NULL && object!=NULL && label->HasBaseline() && object->HasBaseline()) {
-      height-=std::max(label->GetBaseline(),object->GetBaseline())-std::min(label->GetBaseline(),object->GetBaseline());
+    if (label!=NULL && object!=NULL &&
+        label->HasBaseline() && object->HasBaseline()) {
+      height-=std::max(label->GetBaseline(),object->GetBaseline())-
+              std::min(label->GetBaseline(),object->GetBaseline());
     }
 
     if (label!=NULL) {
@@ -117,12 +129,14 @@ namespace Lum {
 
   bool Label::Entry::HasOffset() const
   {
-    return label!=NULL && object!=NULL && label->HasBaseline() && object->HasBaseline();
+    return label!=NULL && object!=NULL &&
+    label->HasBaseline() && object->HasBaseline();
   }
 
   size_t Label::Entry::GetLabelOffset() const
   {
-    if (label!=NULL && object!=NULL && label->HasBaseline() && object->HasBaseline()) {
+    if (label!=NULL && object!=NULL &&
+        label->HasBaseline() && object->HasBaseline()) {
       if (object->GetBaseline()>label->GetBaseline()) {
         return object->GetBaseline()-label->GetBaseline();
       }
@@ -137,7 +151,8 @@ namespace Lum {
 
   size_t Label::Entry::GetObjectOffset() const
   {
-    if (label!=NULL && object!=NULL && label->HasBaseline() && object->HasBaseline()) {
+    if (label!=NULL && object!=NULL &&
+        label->HasBaseline() && object->HasBaseline()) {
       if (label->GetBaseline()>object->GetBaseline()) {
         return label->GetBaseline()-object->GetBaseline();
       }
@@ -329,7 +344,7 @@ namespace Lum {
 
     /*
       If current height is not equal to exspected height, resize until equal
-       or until now object can be resized anymore.
+       or until no object can be resized anymore.
     */
     while (curHeight!=height) {
       int count=0;
@@ -402,6 +417,11 @@ namespace Lum {
       ++iter;
     }
 
+    iter=list.begin();
+    while (iter!=list.end()) {
+      ++iter;
+    }
+
     Group::Layout();
   }
 
