@@ -210,15 +210,21 @@ namespace Lum {
         }
       }
 
+      std::wstring label=action->GetAction().GetDesc().GetLabel();
+
+      if (action->GetAction().GetOpensDialog()) {
+        label=label+L"...";
+      }
+
       if (action->GetAction().GetDesc().HasShortcut()) {
-      menu->AddActionItem(action->GetAction().GetDesc().GetLabel(),
+      menu->AddActionItem(label,
                           /*action->GetImage(),*/
                           action->GetAction().GetAction(),
                           action->GetAction().GetDesc().GetShortcutQualifier(),
                           action->GetAction().GetDesc().GetShortcutKey());
       }
       else {
-        menu->AddActionItem(action->GetAction().GetDesc().GetLabel(),
+        menu->AddActionItem(label,
                             /*action->GetImage(),*/
                             action->GetAction().GetAction());
       }
