@@ -415,6 +415,26 @@ namespace Lum {
         draw->PopForeground();
       }
 
+      size_t Theme::GetHorizontalFuelBarMinWidth() const
+      {
+        return 0;
+      }
+
+      size_t Theme::GetHorizontalFuelBarMinHeight() const
+      {
+        return 0;
+      }
+
+      size_t Theme::GetVerticalFuelBarMinWidth() const
+      {
+        return 0;
+      }
+
+      size_t Theme::GetVerticalFuelBarMinHeight() const
+      {
+        return 0;
+      }
+
       int Theme::GetSubMenuHorizontalOffset() const
       {
         return 0;
@@ -455,6 +475,11 @@ namespace Lum {
         return false;
       }
 
+      unsigned long Theme::GetCursorBlinkTimeMicroSeconds() const
+      {
+        return 600000;
+      }
+
       bool Theme::SubdialogsAlwaysFlexHoriz() const
       {
         return false;
@@ -465,6 +490,11 @@ namespace Lum {
         return false;
       }
 
+      bool Theme::PopupsAreDialogs() const
+      {
+        return false;
+      }
+
       Theme::DialogActionPosition Theme::GetDialogActionPosition() const
       {
         return actionPosHorizButtonRowBelow;
@@ -1571,6 +1601,8 @@ namespace Lum {
           colorNames[Display::tabTextSelectColor]="black";
           colorNames[Display::editTextColor]="black";
           colorNames[Display::editTextFillColor]="white";
+          colorNames[Display::textSmartAColor]="white";
+          colorNames[Display::textSmartBColor]="black";
 
           display->AllocateNamedColor("black",shineColor);
           display->AllocateNamedColor("black",halfShineColor);
@@ -1592,6 +1624,8 @@ namespace Lum {
           colorNames[Display::tabTextSelectColor]="black";
           colorNames[Display::editTextColor]="black";
           colorNames[Display::editTextFillColor]="white";
+          colorNames[Display::textSmartAColor]="black";
+          colorNames[Display::textSmartBColor]="white";
 
           display->AllocateNamedColor("grey95",shineColor);
           display->AllocateNamedColor("grey82",halfShineColor);
@@ -1613,6 +1647,8 @@ namespace Lum {
           colorNames[Display::tabTextSelectColor]="black";
           colorNames[Display::editTextColor]="black";
           colorNames[Display::editTextFillColor]="white";
+          colorNames[Display::textSmartAColor]="black";
+          colorNames[Display::textSmartBColor]="white";
 
           display->AllocateNamedColor("grey95",shineColor);
           display->AllocateNamedColor("grey82",halfShineColor);
