@@ -32,6 +32,10 @@
 #include <X11/extensions/shape.h>
 #include <X11/Xatom.h>
 
+#if defined(LUM_HAVE_LIB_HILDON)
+  #include <hildon/hildon-version.h>
+#endif
+
 #include <Lum/Base/String.h>
 
 #include <Lum/OS/X11/Display.h>
@@ -145,9 +149,13 @@ namespace Lum {
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
-        oldPress(0),lastPress(0),thisPress(0),balloonId(0),
-        window(0),fullScreen(false),xic(0)
+        oldPress(0),lastPress(0),thisPress(0),
+        balloonId(0),
+        window(0),fullScreen(false),
+        customWindowType(0),
+        xic(0)
       {
+        // no code
       }
 
       void Window::SetTitle(const std::wstring& name)
@@ -420,7 +428,7 @@ data        : POINTER TO ARRAY OF LONGINT;*/
             return true;
           }
           else if ((Atom)x11Event.xclient.message_type==XInternAtom(display->display,"_MB_GRAB_TRANSFER",true)) {
-#ifdef HAVE_LIB_HILDON
+#ifdef LUM_HAVE_LIB_HILDON
             TriggerMenu();
 #endif
           }
@@ -540,9 +548,11 @@ data        : POINTER TO ARRAY OF LONGINT;*/
               XFree(wHints);
             }
           }
+
           RecalcWindowPosition();
           draw->OnMap();
           TriggerMaped();
+
           if (grabMouse) {
             MouseGrabOn();
           }
@@ -599,7 +609,7 @@ data        : POINTER TO ARRAY OF LONGINT;*/
             return true;
           }
           break;
-#ifdef HAVE_LIB_HILDON
+#if defined(LUM_HAVE_LIB_HILDON)
         case KeyPress:
           if (dynamic_cast<KeyEvent*>(event)->key==keyF4) {
             TriggerMenu();
@@ -616,6 +626,7 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         case PropertyNotify:
           //std::cout << "Property " << x11Event.xproperty.atom << " has changed!" << std::endl;
           break;
+          break;
         default:
           break;
         }
@@ -686,7 +697,7 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
       void Window::KeyboardGrabOff()
       {
-        //XUngrabKeyboard(display->display,CurrentTime);
+        XUngrabKeyboard(display->display,CurrentTime);
       }
 
 /*
@@ -870,11 +881,37 @@ data        : POINTER TO ARRAY OF LONGINT;*/
                                    display->atoms[Display::netWMWindowTypeAtom],
                                    display->atoms[Display::netWMWindowTypeNormalAtom]);
           break;
+        case typeCustom:
+            if (customWindowType!=0) {
+              display->SetAtomProperty(this,
+                                       display->atoms[Display::netWMWindowTypeAtom],
+                                       customWindowType);
+            }
+          break;
         case typeAuto:
           assert(false);
           break;
         }
 
+#if defined(LUM_HAVE_LIB_HILDON)
+   #if HILDON_CHECK_VERSION(2,1,0)
+        if (type==typeMain) {
+          size_t      stackCount=0;
+          OS::Window *p=GetParent();
+
+          while (p!=NULL) {
+            stackCount++;
+            p=p->GetParent();
+          }
+
+          display->SetIntegerProperty(this,
+                                      XInternAtom(display->display,
+                                                  "_HILDON_STACKABLE_WINDOW",
+                                                  false),
+                                                  stackCount);
+        }
+   #endif
+#endif
         /*
         if (type==typeMain && XInternAtom(display->display,"_NET_REQUEST_FRAME_EXTENTS",true)!=None) {
           Atom           type;
@@ -924,17 +961,19 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         }
 
         wHints->initial_state=NormalState;
-        wHints->input=activate ? True : False;
-        wHints->flags=StateHint | InputHint;
+        wHints->flags=StateHint;
 
         className=Lum::Base::WStringToString(display->GetAppName());
         cHints->res_name=const_cast<char*>(className.c_str());
         cHints->res_class=const_cast<char*>(className.c_str());
 
-        if (type!=typeMenu) {
+        if (type!=typeMenu &&
+            type!=typeMenuPopup &&
+            type!=typeMenuDropdown &&
+            type!=typePopup) {
           OS::Window* window;
 
-          wHints->flags=wHints->flags | WindowGroupHint;
+          wHints->flags|=WindowGroupHint;
 
           window=GetTopWindow();
           if (window!=NULL) {
@@ -977,7 +1016,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 #ifdef HAVE_GETPID
         display->SetCardinalProperty(this,display->atoms[Display::netWMPIDAtom],
                                      getpid());
-
 #endif
 
         SetOpacity(GetOpacity());
@@ -986,7 +1024,7 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
         display->AddWindow(this);
 
-        XMapWindow(display->display,this->window);
+        Show(activate);
 
         return true;
       }
@@ -994,10 +1032,14 @@ data        : POINTER TO ARRAY OF LONGINT;*/
       void Window::Close()
       {
         if (IsOpen() && (window!=0)) {
-          GrabMouse(false);
-          GrabKeyboard(false);
-
           if (IsShown()) {
+            if (grabMouse) {
+              GrabMouse(false);
+            }
+            if (grabKeyboard) {
+              GrabKeyboard(false);
+            }
+
             XUnmapWindow(display->display,window);
 
             XEvent e;
@@ -1006,12 +1048,12 @@ data        : POINTER TO ARRAY OF LONGINT;*/
               XWindowEvent(display->display,window,StructureNotifyMask,&e);
             } while (e.type!=UnmapNotify);
 
-           TriggerUnmaped();
+            TriggerUnmaped();
             draw->OnUnmap();
-          }
 
-          if (display->GetKeyboardManager()!=NULL) {
-            display->GetKeyboardManager()->OnWindowFocusOut(this);
+            if (display->GetKeyboardManager()!=NULL) {
+              display->GetKeyboardManager()->OnWindowFocusOut(this);
+            }
           }
         }
 
@@ -1037,27 +1079,42 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
       bool Window::Show(bool activate)
       {
-        assert(IsOpen() && !IsShown());
+        assert(IsOpen());
+        assert(!IsShown());
 
-        if (!activate) {
-          XWMHints *wHints;
+        XWMHints *wHints;
 
-          wHints=XAllocWMHints();
-          wHints->input=False;
-          wHints->flags=InputHint;
+        wHints=XAllocWMHints();
+        wHints->input=activate ? True : False;
+        wHints->flags=InputHint;
 
-          XSetWMHints(display->display,window,wHints);
-          XFree(wHints);
-        }
+        XSetWMHints(display->display,window,wHints);
+        XFree(wHints);
 
         return XMapWindow(display->display,window)==Success;
       }
 
       bool Window::Hide()
       {
-        assert(IsOpen() && IsShown());
+        bool result;
 
-        return XUnmapWindow(display->display,window)==Success;
+        assert(IsOpen());
+        assert(IsShown());
+
+        if (grabMouse) {
+          GrabMouse(false);
+        }
+        if (grabKeyboard) {
+          GrabKeyboard(false);
+        }
+
+        result=XUnmapWindow(display->display,window)==Success;
+
+        if (display->GetKeyboardManager()!=NULL) {
+          display->GetKeyboardManager()->OnWindowFocusOut(this);
+        }
+
+        return result;
       }
 
       bool Window::GetMousePos(int& x, int& y) const
@@ -1295,6 +1352,12 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
         return true;
       }
+
+      void Window::SetCustomWindowType(Atom type)
+      {
+        customWindowType=type;
+      }
+
     }
   }
 }
