@@ -1307,6 +1307,14 @@ namespace Lum {
       maxWidth=oMaxWidth-background->leftBorder-background->rightBorder;
       maxHeight=oMaxHeight-background->topBorder-background->bottomBorder;
     }
+    else {
+      width=oWidth;
+      height=oHeight;
+      minWidth=oMinWidth;
+      minHeight=oMinHeight;
+      maxWidth=oMaxWidth;
+      maxHeight=oMaxHeight;
+    }
 
 
     if (!horizontalFlex) {
