@@ -88,6 +88,22 @@ namespace Lum {
     boxFrame=OS::display->GetFrame(OS::Display::hscaleFrameIndex);
   }
 
+  bool HSlider::HasBaseline() const
+  {
+    return useScale;
+  }
+
+  size_t HSlider::GetBaseline() const
+  {
+    OS::FontRef font=OS::display->GetFont();
+
+    assert(useScale);
+
+    return scale->GetOHeight()+
+    OS::display->GetSpaceVertical(OS::Display::spaceIntraObject)+
+    boxFrame->topBorder+((int)knob->GetHeight()-(int)font->height)/2+font->ascent;
+  }
+
   void HSlider::DrawKnob()
   {
     OS::DrawInfo *draw=GetDrawInfo();
