@@ -135,32 +135,62 @@ namespace Lum {
     return false;
   }
 
+  void State::PrepareForBackground(OS::DrawInfo* draw)
+  {
+    if (boolModel.Valid() &&
+        !boolModel->IsNull() &&
+        boolModel->IsEnabled()) {
+      if (boolModel->Get()) {
+        draw->selected=true;
+      }
+    }
+    else if (sizeTModel.Valid() &&
+             !sizeTModel->IsNull() &&
+             sizeTModel->IsEnabled()) {
+      if (sizeTModel->Get()==index) {
+        draw->selected=true;
+      }
+    }
+    else {
+      draw->disabled=true;
+    }
+
+    draw->focused=HasFocus();
+    draw->activated=IsMouseActive();
+  }
+
   void State::Draw(int x, int y, size_t w, size_t h)
   {
     OS::DrawInfo *draw=GetDrawInfo();
 
-    if (IsMouseActive()) {
-      draw->activated=true;
-    }
-
-    draw->focused=HasFocus();
-
     Control::Draw(x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
-      draw->activated=false;
-      draw->focused=false;
       return;
     }
 
     /* --- */
 
-    if (boolModel.Valid() && !boolModel->IsNull() && boolModel->Get()) {
-      draw->selected=true;
+    if (boolModel.Valid() &&
+        !boolModel->IsNull() &&
+        boolModel->IsEnabled()) {
+      if (boolModel->Get()) {
+        draw->selected=true;
+      }
     }
-    else if (sizeTModel.Valid() && !sizeTModel->IsNull() && sizeTModel->Get()==index) {
-      draw->selected=true;
+    else if (sizeTModel.Valid() &&
+             !sizeTModel->IsNull() &&
+             sizeTModel->IsEnabled()) {
+      if (sizeTModel->Get()==index) {
+        draw->selected=true;
+      }
     }
+    else {
+      draw->disabled=true;
+    }
+
+    draw->focused=HasFocus();
+    draw->activated=IsMouseActive();
 
     DrawContent(x,y,w,h);
 
