@@ -19,6 +19,7 @@
 
 #include <Lum/String.h>
 
+#include <Lum/OS/Manager/Repository.h>
 #include <Lum/OS/Theme.h>
 
 #include <Lum/Base/String.h>
@@ -29,8 +30,6 @@
 
 namespace Lum {
 
-  #define BLINK_MICRO 600000
-
   static ControllerRef controller(new String::Controller());
 
   String::Controller::Controller()
@@ -205,20 +204,32 @@ namespace Lum {
     return this->model.Valid();
   }
 
-  void String::SetInputHelper(InputHelper *inputHelper)
+  String* String::SetLabel(const std::wstring& label)
+  {
+    this->label=label;
+
+    Redraw();
+
+    return this;
+  }
+
+  String* String::SetInputHelper(InputHelper *inputHelper)
   {
     delete this->inputHelper;
 
     this->inputHelper=inputHelper;
 
     SetRequestsKeyboard(this->inputHelper==NULL);
+
+    return this;
   }
 
   void String::OpenInputHelper()
   {
-    if (//OS::display->GetKeyboardHandler()!=NULL &&
+    if (OS::Manager::repository->GetKeyboardManager()!=NULL &&
         inputHelper!=NULL &&
         !inputHelper->IsOpen()) {
+      inputHelper->SetType(OS::Window::typePopup);
       inputHelper->SetParent(GetWindow());
       inputHelper->SetReference(this);
       inputHelper->Open(this);
@@ -850,7 +861,10 @@ namespace Lum {
   {
     cursorVisible=true;
     OS::display->RemoveTimer(blinkAction);
-    OS::display->AddTimer(0,BLINK_MICRO,blinkAction);
+    if (OS::display->GetTheme()->GetCursorBlinkTimeMicroSeconds()>0) {
+      OS::display->AddTimer(0,OS::display->GetTheme()->GetCursorBlinkTimeMicroSeconds(),
+                            blinkAction);
+    }
   }
 
   /**
@@ -875,6 +889,7 @@ namespace Lum {
   void String::Draw(int x, int y, size_t w, size_t h)
   {
     OS::DrawInfo *draw=GetDrawInfo();
+    bool         drawLabel=false;
 
     draw->focused=HasFocus();
 
@@ -904,6 +919,14 @@ namespace Lum {
     /* value to be printed */
     string=GetValue();
 
+    if (string.size()==0 &&
+        !draw->focused &&
+        model.Valid() &&
+        model->IsEnabled()) {
+      string=label;
+      drawLabel=true;
+    }
+
     draw->PushClip(this->x,this->y,width,height);
 
     if (cursor>string.length()) {
@@ -965,7 +988,13 @@ namespace Lum {
 
     /* Draw the string */
 
-    draw->PushFont(font,OS::Font::normal);
+    if (drawLabel) {
+      draw->PushFont(font,OS::Font::italic);
+    }
+    else{
+      draw->PushFont(font,OS::Font::normal);
+    }
+
     if (Selected()) { /* there exists a selection */
       int         markAPos,markBPos;
       OS::FillRef back=OS::display->GetFill(OS::Display::entryBackgroundFillIndex);
@@ -1041,7 +1070,12 @@ namespace Lum {
       draw->PopClip();
     }
     else {
-      draw->PushForeground(OS::Display::editTextColor);
+      if (drawLabel) {
+        draw->PushForeground(OS::Display::textDisabledColor);
+      }
+      else {
+        draw->PushForeground(OS::Display::editTextColor);
+      }
       draw->DrawString(textPos,yOff+font->ascent,string);
       draw->PopForeground();
     }
@@ -1299,7 +1333,10 @@ namespace Lum {
 
       if (visible && selected && !Selected()) {
         DrawCursor();
-        OS::display->AddTimer(0,BLINK_MICRO,blinkAction);
+        if (OS::display->GetTheme()->GetCursorBlinkTimeMicroSeconds()>0) {
+          OS::display->AddTimer(0,OS::display->GetTheme()->GetCursorBlinkTimeMicroSeconds(),
+                                blinkAction);
+        }
       }
     }
     else if (model==cutAction && cutAction->IsFinished()) {
