@@ -801,7 +801,27 @@ namespace Lum {
     Lum::OS::DrawInfo *draw=GetDrawInfo();
 
     if (!model.Valid() || model->GetRows()==0) {
+      std::wstring emptyText;
+
+      if (model.Valid()) {
+        emptyText=model->GetEmptyText();
+      }
+
       FillWithBackground(draw,x,y,w,h);
+
+      if (!emptyText.empty()) {
+        OS::FontExtent extent;
+
+        font->StringExtent(emptyText,extent);
+
+        draw->PushFont(font);
+        draw->PushForeground(OS::Display::tableTextColor);
+        draw->DrawString(this->x+(width-extent.width) / 2,
+                         this->y+font->ascent+((int)height-(int)font->height) / 2,
+                         emptyText);
+        draw->PopForeground();
+        draw->PopFont();
+      }
       return;
     }
 
