@@ -388,19 +388,18 @@ namespace Lum {
     OS::DrawInfo               *draw=GetDrawInfo();
     int                        xPos,yPos,y2;
 
-    if ((draw->focused || DisplayFocus()) && OS::display->GetType()==OS::Display::typeTextual) {
+    if ((draw->focused || DisplayFocus()) &&
+        OS::display->GetType()==OS::Display::typeTextual) {
       draw->PushForeground(OS::Display::fillTextColor);
     }
-    else {
-      if (parent!=NULL) {
-        draw->PushForeground(parent->GetTextColor(draw));
-      }
-      else if (draw->selected) {
+    else if (parent!=NULL) {
+      draw->PushForeground(parent->GetTextColor(draw));
+    }
+    else if (draw->selected) {
       draw->PushForeground(OS::Display::textSelectColor);
-      }
-      else {
-        draw->PushForeground(OS::Display::textColor);
-      }
+    }
+    else {
+      draw->PushForeground(OS::Display::textColor);
     }
 
     draw->PushClip(x,y,w,h);
@@ -447,9 +446,12 @@ namespace Lum {
           draw->DrawString(xPos-part->hOffset,y2+part->vOffset,part->text);
           draw->PopForeground();
         }
-        else if ((part->style & smart) && OS::display->GetType()!=OS::Display::typeTextual) {
+        else if ((part->style & smart) &&
+                 OS::display->GetType()!=OS::Display::typeTextual) {
+          draw->PushForeground(OS::Display::textSmartAColor);
           draw->DrawString(xPos+1-part->hOffset,y2+part->vOffset,part->text);
-          draw->PushForeground(OS::Display::whiteColor);
+          draw->PopForeground();
+          draw->PushForeground(OS::Display::textSmartBColor);
           draw->DrawString(xPos-part->hOffset,y2-1+part->vOffset,part->text);
           draw->PopForeground();
         }
