@@ -136,23 +136,30 @@ namespace Lum {
 
   void View::Layout()
   {
-    if (hVisible && object->GetHAdjustment()->GetVisible()==object->GetHAdjustment()->GetTotal()) {
+    if (hVisible &&
+        (!object->GetHAdjustment()->IsValid() ||
+         object->GetHAdjustment()->GetVisible()==object->GetHAdjustment()->GetTotal())) {
       hScroller->Hide();
       hVisible=false;
     }
-    else if (!hVisible && object->GetHAdjustment()->GetVisible()<object->GetHAdjustment()->GetTotal()) {
+    else if (!hVisible &&
+             object->GetHAdjustment()->IsValid() &&
+             object->GetHAdjustment()->GetVisible()<object->GetHAdjustment()->GetTotal()) {
       hVisible=true;
     }
-    if (vVisible && object->GetVAdjustment()->GetVisible()==object->GetVAdjustment()->GetTotal()) {
+
+    if (vVisible &&
+        (!object->GetVAdjustment()->IsValid() ||
+         object->GetVAdjustment()->GetVisible()==object->GetVAdjustment()->GetTotal())) {
       vScroller->Hide();
       vVisible=false;
     }
-    else if (!vVisible && object->GetVAdjustment()->GetVisible()<object->GetVAdjustment()->GetTotal()) {
+    else if (!vVisible &&
+             object->GetVAdjustment()->IsValid() &&
+             object->GetVAdjustment()->GetVisible()<object->GetVAdjustment()->GetTotal()) {
       vVisible=true;
     }
 
-    object->CalculateDimension();
-
     size_t tWidth,tHeight;
 
     tWidth=width;
@@ -197,10 +204,18 @@ namespace Lum {
         }
       }
       else if (model==refreshAction && refreshAction->IsFinished()) {
-        if ((hVisible && object->GetHAdjustment()->GetVisible()==object->GetHAdjustment()->GetTotal()) ||
-            (!hVisible && object->GetHAdjustment()->GetVisible()<object->GetHAdjustment()->GetTotal()) ||
-            (vVisible && object->GetVAdjustment()->GetVisible()==object->GetVAdjustment()->GetTotal()) ||
-            (!vVisible && object->GetVAdjustment()->GetVisible()<object->GetVAdjustment()->GetTotal())) {
+        if ((hVisible &&
+             (!object->GetHAdjustment()->IsValid() ||
+              object->GetHAdjustment()->GetVisible()==object->GetHAdjustment()->GetTotal())) ||
+            (!hVisible &&
+             object->GetHAdjustment()->IsValid() &&
+             object->GetHAdjustment()->GetVisible()<object->GetHAdjustment()->GetTotal()) ||
+            (vVisible &&
+             (!object->GetVAdjustment()->IsValid() ||
+              object->GetVAdjustment()->GetVisible()==object->GetVAdjustment()->GetTotal())) ||
+            (!vVisible &&
+             object->GetVAdjustment()->IsValid() &&
+             object->GetVAdjustment()->GetVisible()<object->GetVAdjustment()->GetTotal())) {
           SetRelayout();
           Redraw();
         }
@@ -209,5 +224,26 @@ namespace Lum {
 
     Group::Resync(model,msg);
   }
+
+  View* View::Create(bool horizontalFlex, bool verticalFlex)
+  {
+    View *v;
+
+    v=new View();
+    v->SetFlex(horizontalFlex,verticalFlex);
+
+    return v;
+  }
+
+  View* View::Create(Scrollable* object, bool horizontalFlex, bool verticalFlex)
+  {
+    View *v;
+
+    v=new View();
+    v->SetFlex(horizontalFlex,verticalFlex);
+    v->SetObject(object);
+
+    return v;
+  }
 }
 
