@@ -916,6 +916,11 @@ namespace Lum {
     window->SetType(type);
   }
 
+  OS::Window::Type Window::GetType() const
+  {
+    return window->GetType();
+  }
+
   void Window::SetPosition(int x, int y)
   {
     window->SetPos(x,y);
